# Generated by Django 2.2.9 on 2020-02-04 11:33

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("django_ip_access", "0001_initial")]

    operations = [
        migrations.AlterField(
            model_name="ipaddress",
            name="user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL
            ),
        )
    ]
